@@ -1,19 +1,9 @@
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Dict, Optional
 
 from pydantic import BaseModel
 
 
-class SynapseDataModel(BaseModel):
-    id: str
-    name: str
-    type: str
-
-
-class SynapseWorkspace(SynapseDataModel):
-    properties: Any
-
-
 class SynapseDatabase(BaseModel):
     id: int
     name: str
@@ -21,24 +11,6 @@ class SynapseDatabase(BaseModel):
     collation_name: str
 
 
-class WorkspaceDatabase(SynapseDataModel):
-    properties: Any
-
-
-class DedicatedSqlPoolSchema(SynapseDataModel):
-    pass
-
-
-class DedicatedSqlPoolColumn(SynapseDataModel):
-    properties: Any
-
-
-class DedicatedSqlPoolTable(SynapseDataModel):
-    properties: Any
-    sqlSchema: Optional[DedicatedSqlPoolSchema]
-    columns: Optional[List]
-
-
 class SynapseColumn(BaseModel):
     name: str
     type: str
