@@ -1,18 +1,13 @@
 from datetime import datetime
 from typing import Any, Dict, Iterable, List
 
-from metaphor.common.api_request import get_request
 from metaphor.common.logger import get_logger
 from metaphor.common.utils import to_utc_time
 from metaphor.synapse.model import (
-    DedicatedSqlPoolSchema,
-    DedicatedSqlPoolTable,
     SynapseColumn,
     SynapseDatabase,
     SynapseQueryLog,
     SynapseTable,
-    SynapseWorkspace,
-    WorkspaceDatabase,
 )
 
 try:
@@ -25,42 +20,30 @@ logger = get_logger()
 
 
 class WorkspaceClient:
-    AZURE_MANGEMENT_ENDPOINT = "https://management.azure.com"
-
     def __init__(
         self,
-        workspace: SynapseWorkspace,
-        subscription_id: str,
+        workspace_name: str,
         username: str,
         password: str,
-        management_headers: Dict[str, str],
     ):
-        self._workspace = workspace
-        self._subscription_id = subscription_id
-        self._azure_management_headers = management_headers
-        self._dev_endpoint = workspace.properties["connectivityEndpoints"]["dev"]
-        self._sql_query_endpoint = workspace.properties["connectivityEndpoints"]["sql"]
-        self._sql_on_demand_query_endpoint = workspace.properties[
-            "connectivityEndpoints"
-        ]["sqlOnDemand"]
-        self._account_endpoint = workspace.properties["defaultDataLakeStorage"][
-            "accountUrl"
-        ]
-        self._default_file_system = workspace.properties["defaultDataLakeStorage"][
-            "filesystem"
-        ]
-        index1 = workspace.id.index("/resourceGroups/")
-        index2 = workspace.id.index("/providers/")
-        self._resource_group_name = workspace.id[index1 + 16 : index2]
+        self.workspace_name = workspace_name
+        self._sql_query_endpoint = f"{workspace_name}.sql.azuresynapse.net"
+        self._sql_on_demand_query_endpoint = (
+            f"{workspace_name}-ondemand.sql.azuresynapse.net"
+        )
+        self._username = username
+        self._password = password
 
-        self.username = username
-        self.password = password
-
-    def get_databases(self) -> Iterable[SynapseDatabase]:
+    def get_databases(self, is_dedicated: bool = False) -> Iterable[SynapseDatabase]:
         query_str = """
             SELECT database_id, name, create_date, collation_name from sys.databases where name != 'master';
         """
-        rows = self._sql_query_fetch_all(self._sql_on_demand_query_endpoint, query_str)
+        end_point = (
+            self._sql_query_endpoint
+            if is_dedicated
+            else self._sql_on_demand_query_endpoint
+        )
+        rows = self._sql_query_fetch_all(end_point, query_str)
         for row in rows:
             yield SynapseDatabase(
                 id=row[0],
@@ -69,17 +52,9 @@ class WorkspaceClient:
                 collation_name=row[3],
             )
 
-    def get_dedicated_sql_pool_databases(self) -> List[WorkspaceDatabase]:
-        # https://learn.microsoft.com/en-us/rest/api/synapse/sql-pools/list-by-workspace?tabs=HTTP
-        url = f"{self.AZURE_MANGEMENT_ENDPOINT}/subscriptions/{self._subscription_id}/resourceGroups/{self._resource_group_name}/providers/Microsoft.Synapse/workspaces/{self._workspace.name}/sqlPools?api-version=2021-06-01"
-        return get_request(
-            url,
-            self._azure_management_headers,
-            List[WorkspaceDatabase],
-            transform_response=lambda r: r.json()["value"],
-        )
-
-    def get_tables(self, database_name: str) -> List[SynapseTable]:
+    def get_tables(
+        self, database_name: str, is_dedicated: bool = False
+    ) -> List[SynapseTable]:
         query_str = """
         SELECT t.object_id, t.name AS table_name, s.name AS schema_name
             ,t.type, t.create_date
@@ -106,7 +81,11 @@ class WorkspaceClient:
                 ON fkc.constraint_object_id = fk.object_id
         ) AS fky ON t.object_id = fky.object_id and c.column_id = fky.column_id
         """
-        end_point = self._sql_on_demand_query_endpoint
+        end_point = (
+            self._sql_query_endpoint
+            if is_dedicated
+            else self._sql_on_demand_query_endpoint
+        )
         rows = self._sql_query_fetch_all(end_point, query_str, database_name)
 
         table_dict: Dict[str, SynapseTable] = {}
@@ -133,7 +112,7 @@ class WorkspaceClient:
                         WHERE ext.object_id = '{row[0]}';
                     """
                     rows = self._sql_query_fetch_all(
-                        self._sql_on_demand_query_endpoint, query_str, database_name
+                        end_point, query_str, database_name
                     )
                     if len(rows) == 1:
                         table.external_source = rows[0][0]
@@ -159,41 +138,6 @@ class WorkspaceClient:
 
         return list(table_dict.values())
 
-    def get_dedicated_sql_pool_tables(
-        self, database_name: str
-    ) -> List[DedicatedSqlPoolTable]:
-        api_version = "api-version=2021-06-01"
-        # https://learn.microsoft.com/en-us/rest/api/synapse/sql-pool-schemas/list?tabs=HTTP
-        url = f"{self.AZURE_MANGEMENT_ENDPOINT}/subscriptions/{self._subscription_id}/resourceGroups/{self._resource_group_name}/providers/Microsoft.Synapse/workspaces/{self._workspace.name}/sqlPools/{database_name}"
-        sql_pool_tables = []
-        schemas = get_request(
-            f"{url}/schemas?{api_version}",
-            self._azure_management_headers,
-            List[DedicatedSqlPoolSchema],
-            transform_response=lambda r: r.json()["value"],
-        )
-
-        for schema in schemas:
-            tables = get_request(
-                # https://learn.microsoft.com/en-us/rest/api/synapse/sql-pool-tables/list-by-schema?tabs=HTTP
-                f"{url}/schemas/{schema.name}/tables?{api_version}",
-                self._azure_management_headers,
-                List[DedicatedSqlPoolTable],
-                transform_response=lambda r: r.json()["value"],
-            )
-
-            for table in tables:
-                table.sqlSchema = schema
-                table.columns = get_request(
-                    # https://learn.microsoft.com/en-us/rest/api/synapse/sql-pool-table-columns/list-by-table-name?tabs=HTTP
-                    f"{url}/schemas/{schema.name}/tables/{table.name}/columns?{api_version}",
-                    self._azure_management_headers,
-                    List[Any],
-                    transform_response=lambda r: r.json()["value"],
-                )
-                sql_pool_tables.append(table)
-        return sql_pool_tables
-
     def get_sql_pool_query_logs(
         self, start_date: datetime, end_date: datetime
     ) -> Iterable[SynapseQueryLog]:
@@ -269,18 +213,25 @@ class WorkspaceClient:
     def _sql_query_fetch_all(
         self, endpoint: str, query_str: str, database: str = ""
     ) -> List[Any]:
-        server = endpoint
-        database_str = f"{database}" if len(database) > 0 else ""
-        conn = pymssql.connect(
-            server=server,
-            user=f'{self.username}@{endpoint.split(".")[0]}',
-            password=self.password,
-            database=database_str,
-            conn_properties="",
-        )
-        cursor = conn.cursor()
-        cursor.execute(query_str)
-        rows = cursor.fetchall()
-        cursor.close()
-        conn.close()
-        return rows
+        rows = []
+        try:
+            server = endpoint
+            database_str = f"{database}" if len(database) > 0 else ""
+            conn = pymssql.connect(
+                server=server,
+                user=f'{self._username}@{endpoint.split(".")[0]}',
+                password=self._password,
+                database=database_str,
+                conn_properties="",
+            )
+            cursor = conn.cursor()
+            cursor.execute(query_str)
+            rows = cursor.fetchall()
+            cursor.close()
+            conn.close()
+        except Exception as ex:
+            logger.exception(
+                f"endpoint[{endpoint}] \n database:[{database}] \n sql query error: {ex}"
+            )
+        finally:
+            return rows
